About the Copyright Holders
===========================

*   Copyright (c) 2023 pvlib python Contributors
*   Copyright (c) 2014 PVLIB python Development Team
*   Copyright (c) 2013 Sandia National Laboratories

    The pvlib python Contributors comprises all authors of content of the pvlib python project.
    A complete list of contributors can be found in the documentation.

    The PVLIB python Development Team is the collection of developers of the
    pvlib python project. Members of this team are included in the pvlib python Contributors.

    Sandia National Laboratories originally developed pvlib python based on code in
    PVLib MATLAB.


Our Copyright Policy
====================

pvlib python uses a shared copyright model. Each contributor maintains copyright
over their contributions to pvlib python. However, it is important to note that
these contributions are typically only changes to the repositories. Thus,
the pvlib python source code, in its entirety, is not the copyright of any single
person or institution. Instead, it is the collective copyright of the
Contributors. If individual contributors want to make explicit their copyright
of the contributions they have made,
they should indicate their copyright using in-line comments in the code submitted
to the pvlib python repository, with the understanding that by contributing, they
grant the pvlib-python license.

License
=======

pvlib python is distributed under a 3-clause BSD license.
